==> stepfunctions-tasks-1.85.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/RunEcsEc2Task.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * (deprecated) Run an ECS/EC2 Task in a StepFunctions workflow.
 * <p>
 * @deprecated - replaced by `EcsRunTask`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.15.0 (build 585166b)", date = "2021-01-14T21:02:43.615Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.RunEcsEc2Task")
public class RunEcsEc2Task extends software.amazon.awscdk.services.stepfunctions.tasks.EcsRunTaskBase {

    protected RunEcsEc2Task(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected RunEcsEc2Task(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public RunEcsEc2Task(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create() {
            return new Builder();
        }

        private final software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps.Builder props;

        private Builder() {
            this.props = new software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps.Builder();
        }

        /**
         * The topic to run the task on.
         * <p>
         * @return {@code this}
         * @param cluster The topic to run the task on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cluster(final software.amazon.awscdk.services.ecs.ICluster cluster) {
            this.props.cluster(cluster);
            return this;
        }

        /**
         * Task Definition used for running tasks in the service.
         * <p>
         * Note: this must be TaskDefinition, and not ITaskDefinition,
         * as it requires properties that are not known for imported task definitions
         * <p>
         * @return {@code this}
         * @param taskDefinition Task Definition used for running tasks in the service. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder taskDefinition(final software.amazon.awscdk.services.ecs.TaskDefinition taskDefinition) {
            this.props.taskDefinition(taskDefinition);
            return this;
        }

        /**
         * Container setting overrides.
         * <p>
         * Key is the name of the container to override, value is the
         * values you want to override.
         * <p>
         * Default: - No overrides
         * <p>
         * @return {@code this}
         * @param containerOverrides Container setting overrides. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder containerOverrides(final java.util.List<? extends software.amazon.awscdk.services.stepfunctions.tasks.ContainerOverride> containerOverrides) {
            this.props.containerOverrides(containerOverrides);
            return this;
        }

        /**
         * The service integration pattern indicates different ways to call RunTask in ECS.
         * <p>
         * The valid value for Lambda is FIRE_AND_FORGET, SYNC and WAIT_FOR_TASK_TOKEN.
         * <p>
         * Default: FIRE_AND_FORGET
         * <p>
         * @return {@code this}
         * @param integrationPattern The service integration pattern indicates different ways to call RunTask in ECS. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder integrationPattern(final software.amazon.awscdk.services.stepfunctions.ServiceIntegrationPattern integrationPattern) {
            this.props.integrationPattern(integrationPattern);
            return this;
        }

        /**
         * Placement constraints.
         * <p>
         * Default: No constraints
         * <p>
         * @return {@code this}
         * @param placementConstraints Placement constraints. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder placementConstraints(final java.util.List<? extends software.amazon.awscdk.services.ecs.PlacementConstraint> placementConstraints) {
            this.props.placementConstraints(placementConstraints);
            return this;
        }

        /**
         * Placement strategies.
         * <p>
         * Default: No strategies
         * <p>
         * @return {@code this}
         * @param placementStrategies Placement strategies. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder placementStrategies(final java.util.List<? extends software.amazon.awscdk.services.ecs.PlacementStrategy> placementStrategies) {
            this.props.placementStrategies(placementStrategies);
            return this;
        }

        /**
         * Existing security group to use for the task's ENIs.
         * <p>
         * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
         * <p>
         * Default: A new security group is created
         * <p>
         * @return {@code this}
         * @param securityGroup Existing security group to use for the task's ENIs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder securityGroup(final software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup) {
            this.props.securityGroup(securityGroup);
            return this;
        }

        /**
         * In what subnets to place the task's ENIs.
         * <p>
         * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
         * <p>
         * Default: Private subnets
         * <p>
         * @return {@code this}
         * @param subnets In what subnets to place the task's ENIs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder subnets(final software.amazon.awscdk.services.ec2.SubnetSelection subnets) {
            this.props.subnets(subnets);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task build() {
            return new software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task(
                this.props.build()
            );
        }
    }
}

==> stepfunctions-tasks-1.97.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/RunEcsEc2Task.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * (deprecated) Run an ECS/EC2 Task in a StepFunctions workflow.
 * <p>
 * @deprecated - replaced by `EcsRunTask`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.27.0 (build 07d848a)", date = "2021-04-06T14:02:42.130Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.RunEcsEc2Task")
public class RunEcsEc2Task extends software.amazon.awscdk.services.stepfunctions.tasks.EcsRunTaskBase {

    protected RunEcsEc2Task(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected RunEcsEc2Task(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public RunEcsEc2Task(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create() {
            return new Builder();
        }

        private final software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps.Builder props;

        private Builder() {
            this.props = new software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2TaskProps.Builder();
        }

        /**
         * The topic to run the task on.
         * <p>
         * @return {@code this}
         * @param cluster The topic to run the task on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cluster(final software.amazon.awscdk.services.ecs.ICluster cluster) {
            this.props.cluster(cluster);
            return this;
        }

        /**
         * Task Definition used for running tasks in the service.
         * <p>
         * Note: this must be TaskDefinition, and not ITaskDefinition,
         * as it requires properties that are not known for imported task definitions
         * <p>
         * @return {@code this}
         * @param taskDefinition Task Definition used for running tasks in the service. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder taskDefinition(final software.amazon.awscdk.services.ecs.TaskDefinition taskDefinition) {
            this.props.taskDefinition(taskDefinition);
            return this;
        }

        /**
         * Container setting overrides.
         * <p>
         * Key is the name of the container to override, value is the
         * values you want to override.
         * <p>
         * Default: - No overrides
         * <p>
         * @return {@code this}
         * @param containerOverrides Container setting overrides. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder containerOverrides(final java.util.List<? extends software.amazon.awscdk.services.stepfunctions.tasks.ContainerOverride> containerOverrides) {
            this.props.containerOverrides(containerOverrides);
            return this;
        }

        /**
         * The service integration pattern indicates different ways to call RunTask in ECS.
         * <p>
         * The valid value for Lambda is FIRE_AND_FORGET, SYNC and WAIT_FOR_TASK_TOKEN.
         * <p>
         * Default: FIRE_AND_FORGET
         * <p>
         * @return {@code this}
         * @param integrationPattern The service integration pattern indicates different ways to call RunTask in ECS. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder integrationPattern(final software.amazon.awscdk.services.stepfunctions.ServiceIntegrationPattern integrationPattern) {
            this.props.integrationPattern(integrationPattern);
            return this;
        }

        /**
         * (deprecated) Placement constraints.
         * <p>
         * Default: No constraints
         * <p>
         * @return {@code this}
         * @param placementConstraints Placement constraints. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder placementConstraints(final java.util.List<? extends software.amazon.awscdk.services.ecs.PlacementConstraint> placementConstraints) {
            this.props.placementConstraints(placementConstraints);
            return this;
        }

        /**
         * (deprecated) Placement strategies.
         * <p>
         * Default: No strategies
         * <p>
         * @return {@code this}
         * @param placementStrategies Placement strategies. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder placementStrategies(final java.util.List<? extends software.amazon.awscdk.services.ecs.PlacementStrategy> placementStrategies) {
            this.props.placementStrategies(placementStrategies);
            return this;
        }

        /**
         * (deprecated) Existing security group to use for the task's ENIs.
         * <p>
         * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
         * <p>
         * Default: A new security group is created
         * <p>
         * @return {@code this}
         * @param securityGroup Existing security group to use for the task's ENIs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder securityGroup(final software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup) {
            this.props.securityGroup(securityGroup);
            return this;
        }

        /**
         * (deprecated) In what subnets to place the task's ENIs.
         * <p>
         * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
         * <p>
         * Default: Private subnets
         * <p>
         * @return {@code this}
         * @param subnets In what subnets to place the task's ENIs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder subnets(final software.amazon.awscdk.services.ec2.SubnetSelection subnets) {
            this.props.subnets(subnets);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task build() {
            return new software.amazon.awscdk.services.stepfunctions.tasks.RunEcsEc2Task(
                this.props.build()
            );
        }
    }
}
